==> phpwebthings-0.6.0.zip: phpwebthings-0.6.0/lang/msg_enus.php <==
<?php
// english file for phpwebthings - Paulo Assis <paulo@phpdbform.com>
$lang = array(
"CHARSET"=>"iso-8859-1",
//general
"ACTIVATE_TITLE"=>"Account activated!",
"ADD_USERS"=>"Add users",
"REPLIES_TO"=>"Replies to",
"PREVIOUS_MSG"=>"Previous message in thread",
"BACK_FORUM"=>"Back to forum",
"OPTION_NONE"=>"none",
"GO_BACK"=>"Go Back",
"PAGE_PROCESSED"=>"Page processed in %.4f seconds",

// general not logged
"NOT_LOGGED_ONLINE"=>"Sorry, but you need to login to see the online users. If you don't have a login, why don't you register? It's free!",
"NOT_LOGGED_MYACCT"=>"Sorry, but you need to login to edit your account. If you don't have a login, why don't you register? It's free!",

//home
"HOME_TITLE"=>"Home",

//error messages
"ERROR_TITLE"=>"*** ERROR ***",
"ERROR_01"=>"You can't post a message without a title and/or a text",
"ERROR_02"=>"You need to provide a title<br>",
"ERROR_03"=>"You need to provide a text<br>",
"ERROR_04"=>"An error ocurred trying to execute SQL commands",
"ERROR_05"=>"Error opening dir",
"ERROR_06"=>"banner not found",
"ERROR_07"=>"file not found",
"ERROR_08"=>"Invalid e-mail<br>",
"ERROR_09"=>"E-mail not found!<br>",
"ERROR_10"=>"Parser error: ",
"ERROR_11"=>"Action denied",

// not logged messages
//NOT_LOGGED_ONLINE
//NOT_LOGGED_MYACCT

// MyAccount / NewUser
"MYACCT_TITLE"=>"My Account",
"MYACCT_INFO"=>"My Account Info",
"MYACCT_TEXT"=>"All data entered here (except the e-mail) may be visible for other registered users.",
"MYACCT_FORM_LOGIN"=>"Login",
"MYACCT_FORM_REALNAME"=>"Real Name",
"MYACCT_FORM_PASSWD_INFO"=>"If don't want to change your password, leave the password fields blank",
"MYACCT_FORM_PASSWD"=>"Password",
"MYACCT_FORM_PASSWD2"=>"Confirm Password",
"MYACCT_FORM_EMAIL"=>"E-mail (the account will be actived with the e-mail)",
"MYACCT_FORM_SEX"=>"Sex",
"MYACCT_FORM_COUNTRY"=>"Country",
"MYACCT_FORM_CITY"=>"City",
"MYACCT_FORM_STATE"=>"State/Provice",
"MYACCT_FORM_RCVNEWS"=>"Receive news from this site in your e-mail?",
"MYACCT_FORM_RCVREL"=>"Receive an e-mail when a new file is released?",
"MYACCT_FORM_URL"=>"Your site: (begin with http://)",
"MYACCT_FORM_OBS"=>"Comments about you:",
"MYACCT_FORM_SUBMIT"=>"Send",
"MYACCT_NEWSPOSTED"=>"News posted",
"MYACCT_COMMENTSPOSTED"=>"Comments posted",
"MYACCT_FAQPOSTED"=>"FAQs posted",
"MYACCT_DATEACTIVATED"=>"Member since",
"MYACCT_LASTVISIT"=>"Last login",
"MYACCT_NUMLOGINS"=>"Total visits",
"MYACCT_LOGGED"=>"You can't register because you already registered at our site.",

"MYACCT_USER_BOOK"=>"My user list",
"MYACCT_ADD_USER"=>"add user to my book",
"MYACCT_USER_ADDED"=>"User added",
"MYACCT_DEL_USER"=>"delete user from my book",
"MYACCT_USER_DELETED"=>"User removed from your book",
"MYACCT_PROFILE"=>"User profile for",

"MYACCT_INS_ERROR_01"=>"You must enter a password",
"MYACCT_INS_ERROR_02"=>"The password fields differs",
"MYACCT_INS_ERROR_03"=>"Please enter name",
"MYACCT_INS_ERROR_04"=>"Please use only alphanumeric and \'_,.,-\' characters on the name",
"MYACCT_INS_ERROR_05"=>"Please enter country",
"MYACCT_INS_ERROR_06"=>"This e-mail is already registered! If you want to delete it from this database, send an e-mail to",
"MYACCT_INS_ERROR_07"=>"This login is already registered!<br>Please choose another name",
"MYACCT_INVALID_VALUE"=>"Invalid value for question",
"MYACCT_EMAIL_CHANGED_TITLE"=>"E-mail changed",
"MYACCT_EMAIL_CHANGED_TEXT"=>"Your new e-mail will only be changed after activating it. In a few minutes you will receive instructions of how activate it on the new e-mail you informed (%s). <b>Until there the old e-mail still works.</b>",
"MYACCT_EMAIL_CHANGED_MAIL_TITLE"=>"Changing your e-mail at %s",
"MYACCT_EMAIL_CHANGED_MAIL_TEXT"=>"Hi %s!\nYou are changing your e-mail at %s site!\nFor activating your new e-mail, go to %s\n\nBest Regards,\n%s",
"MYACCT_EMAIL_CHANGED_OK"=>"Your e-mail has been changed!",
"MYACCT_EMAIL_CHANGED_ERROR"=>"User/session invalid.",

"NEWUSER_TITLE"=>"New user",
"NEWUSER_MAIL_TITLE"=>"%s registration",
"NEWUSER_MAIL_TEXT"=>"Hi %s!\nThanks for registering at %s site!\nFor activating your account, go to %s\n\nBest Regards,%s",
"NEWUSER_MSG_TITLE"=>"You're almost registered",
"NEWUSER_MSG_TEXT"=>"<b>Thanks</b> for registering with our site!<br><br>Your account isn't active yet, in a few minutes you will receive an e-mail explaining how to activate your registration.",
"NEWUSER_MSG_TITLE2"=>"Thanks for resgistering!",
"NEWUSER_MSG_TEXT2"=>"<b>Thanks</b> for registering with our site!<br><br>Now you can login at our site.",
"NEWUSER_FORM_TITLE"=>"Register",
"NEWUSER_ACTIVATE_ERROR"=>"User/session invalid or account already registred.",
"NEWUSER_ACTIVATED"=>"Your account has been activated! Now you can post messages in the forums and send messages to others users on this site. To see the list of users and add them to your list to send them messages, go to \"My Account\" and click in the \"add users\".<br><br>Thanks for registering!",
"NEW_USER_LINK"=>"Register",
//Login
"LOGIN_TITLE"=>"Login",
"LOGIN_NAME"=>"Login:",
"LOGIN_PASSWD"=>"Password:",
"LOGIN_BUTTON"=>"Login",
"LOGIN_REGISTER"=>"Register, it's free!",
"LOGIN_LOST_PWD"=>"Lost your password?",
"LOGIN_WELCOME"=>"Welcome %s",
"LOGIN_LOGOUT"=>"logout",
"LOGIN_AUTOLOGIN"=>"remember me",

//Users online
"USERS_ONLINE"=>"Users Online",
"USERS_ONLINE_TEXT"=>"There are:<br>%d registered users<br>and %d guests %sonline%s now.",

//List users
"LIST_USERS_TITLE"=>"User list",

// Lost your password?
"PASSWD_TITLE"=>"Password Recovery",
"PASSWD_MAIL_TITLE"=>"Password recovery at ",
"PASSWD_MAIL_TEXT1"=>"You've requested we to send you your password at %s\n\nlogin: %s\npassword: %s",
"PASSWD_MAIL_TEXT2"=>"But your account isn't active, to activate your account, please go to the url below:\n",
"PASSWD_MAIL_DONE"=>"An e-mail was sent for you with your login.",
"PASSWD_MAIL_ERROR"=>"Could not send the e-mail. Internal error.<br>",
"PASSWD_TEXT"=>"Lost your password? Need to get the activation e-mail again? We can send it for you! Just fill the form with your e-mail and we will send you an e-mail with your login. Use it only to retrieve YOUR password.",
"PASSWD_FORM_EMAIL"=>"Enter your e-mail:",
"PASSWD_FORM_SUBMIT"=>"Recover password",

//stats
"STATS_TITLE"=>"Statistics",
"STATS_USERS"=>"Users registered",
"STATS_ACTIVE"=>"Active",
"STATS_NOTACTIVE"=>"Not active",
"STATS_TOTAL"=>"Total",
"STATS_TOPTEN"=>"Topten countries",
"STATS_LAST_WEEK"=>"New users this week",
"STATS_LAST_MONTHS"=>"New users / 3 months",

//send e-mail
"SENDMAIL_MSG_HDR"=>"Hello, %s, \n\n",
"SENDMAIL_MSG_FTR"=>"\n\nSee you,\n\n%s\n\nThis e-mail was sent because you registered at %s. If you don't want to receive any e-mail from us, please edit your account profile at this site.",
"SENDMAIL_MAIL_SENT"=>"sent",
"SENDMAIL_USER"=>"User",
"SENDMAIL_EMAIL"=>"E-mail",
"SENDMAIL_COUNTRY"=>"Country",
"SENDMAIL_SEND"=>"Send",
"SENDMAIL_TEXT"=>"Text",
"SENDMAIL_SUBMIT"=>"Send e-mail",
"SENDMAIL_ACCTO"=>"Send e-mail to users that:",
"SENDMAIL_ACCNEWS"=>"Accepts news",
"SENDMAIL_ACCFREL"=>"Accepts new file releases",
"SENDMAIL_CONTINUE"=>"Continue sending",

// Avatars
"AVATAR_TITLE"=>"Choose your Avatar",
"AVATAR_NONE"=>"none/remove current",
"AVATAR_SELECT"=>"Select your avatar:",
"AVATAR_UPLOAD"=>"or upload a new avatar: (100x100).(jpg|gif|png)",
);

//

?>

==> phpwebthings-1.0.zip: phpwebthings-1.0/lang/msg_enus.php <==
<?php
// english file for phpwebthings - Paulo Assis <paulo@phpdbform.com>
$lang = array(
"CHARSET"=>"iso-8859-1",
//general
"ACTIVATE_TITLE"=>"Account activated!",
"ADD_USERS"=>"Add users",
"REPLIES_TO"=>"Replies to",
"PREVIOUS_MSG"=>"Previous message in thread",
"BACK_FORUM"=>"Back to forum",
"OPTION_NONE"=>"none",
"GO_BACK"=>"Go Back",
"PAGE_PROCESSED"=>"Page processed in %.4f seconds",

// general not logged
"NOT_LOGGED_ONLINE"=>"We apologize, but you need to login to see the online users. If you don't have an account, why don't you register? It's free!",
"NOT_LOGGED_MYACCT"=>"We apologize, but you need to login to edit your account. If you don't have an account, why don't you register? It's free!",
"NOT_LOGGED"=>"We apologize, but you need to login to use this feature. If you don't have an account, why don't you register? It's free!",

//home
"HOME_TITLE"=>"Home",

//error messages
"ERROR_TITLE"=>"*** ERROR ***",
"ERROR_01"=>"You cannot post a message without a title and/or a text",
"ERROR_02"=>"You need to provide a title<br>",
"ERROR_03"=>"You need to provide some text<br>",
"ERROR_04"=>"An error occurred trying to execute SQL commands",
"ERROR_05"=>"Error opening dir",
"ERROR_06"=>"banner not found",
"ERROR_07"=>"file not found",
"ERROR_08"=>"Invalid e-mail<br>",
"ERROR_09"=>"E-mail not found!<br>",
"ERROR_10"=>"Parser error: ",
"ERROR_11"=>"Action denied",

// not logged messages
//NOT_LOGGED_ONLINE
//NOT_LOGGED_MYACCT

// MyAccount / NewUser
"MYACCT_TITLE"=>"My Account",
"MYACCT_INFO"=>"My Account Info",
"MYACCT_TEXT"=>"All data entered here (except the e-mail) may be visible for other registered users.",
"MYACCT_FORM_LOGIN"=>"Login",
"MYACCT_FORM_REALNAME"=>"Real Name",
"MYACCT_FORM_PASSWD_INFO"=>"If you do not want to change your password, leave the password fields blank",
"MYACCT_FORM_PASSWD"=>"Password",
"MYACCT_FORM_PASSWD2"=>"Confirm Password",
"MYACCT_FORM_EMAIL"=>"E-mail (the account will be actived with the e-mail)",
"MYACCT_FORM_SEX"=>"Sex",
"MYACCT_FORM_COUNTRY"=>"Country",
"MYACCT_FORM_CITY"=>"City",
"MYACCT_FORM_STATE"=>"State/Province",
"MYACCT_FORM_RCVNEWS"=>"Receive news from this site in your e-mail?",
"MYACCT_FORM_RCVREL"=>"Receive an e-mail when a new file is released?",
"MYACCT_FORM_URL"=>"Your site: (begin with http://)",
"MYACCT_FORM_OBS"=>"Comments about you:",
"MYACCT_FORM_SUBMIT"=>"Send",
"MYACCT_NEWSPOSTED"=>"News posted",
"MYACCT_COMMENTSPOSTED"=>"Comments posted",
"MYACCT_FAQPOSTED"=>"FAQs posted",
"MYACCT_DATEACTIVATED"=>"Member since",
"MYACCT_LASTVISIT"=>"Last login",
"MYACCT_NUMLOGINS"=>"Total visits",
"MYACCT_LOGGED"=>"Registration Error:  You have already registered at our site.",

"MYACCT_USER_BOOK"=>"My user list",
"MYACCT_ADD_USER"=>"add user to my book",
"MYACCT_USER_ADDED"=>"User added",
"MYACCT_DEL_USER"=>"delete user from my book",
"MYACCT_USER_DELETED"=>"User removed from your book",
"MYACCT_PROFILE"=>"User profile for",

"MYACCT_INS_ERROR_01"=>"You must enter a password",
"MYACCT_INS_ERROR_02"=>"The password fields differs",
"MYACCT_INS_ERROR_03"=>"Please enter name",
"MYACCT_INS_ERROR_04"=>"Please use only alphanumeric and \'_,.,-\' characters on the name",
"MYACCT_INS_ERROR_05"=>"Please enter country",
"MYACCT_INS_ERROR_06"=>"This e-mail is already registered! If you want to delete it from this database, send an e-mail to",
"MYACCT_INS_ERROR_07"=>"This login is already registered!<br>Please choose another name",
"MYACCT_INVALID_VALUE"=>"Invalid value for question",
"MYACCT_EMAIL_CHANGED_TITLE"=>"E-mail changed",
"MYACCT_EMAIL_CHANGED_TEXT"=>"Your new e-mail will only be changed after activating it. In a few minutes you will receive instructions of how activate it on the new e-mail you informed (%s). <b>Until there the old e-mail still works.</b>",
"MYACCT_EMAIL_CHANGED_MAIL_TITLE"=>"Changing your e-mail at %s",
"MYACCT_EMAIL_CHANGED_MAIL_TEXT"=>"Hi %s!\nYou are changing your e-mail at %s site!\nFor activating your new e-mail, go to %s\n\nBest Regards,\n%s",
"MYACCT_EMAIL_CHANGED_OK"=>"Your e-mail has been changed!",
"MYACCT_EMAIL_CHANGED_ERROR"=>"User/session invalid.",

"NEWUSER_TITLE"=>"New user",
"NEWUSER_MAIL_TITLE"=>"%s registration",
"NEWUSER_MAIL_TEXT"=>"Hi %s!\nThanks for registering at %s site!\nFor activating your account, go to %s\n\nBest Regards,%s",
"NEWUSER_MSG_TITLE"=>"You're almost registered",
"NEWUSER_MSG_TEXT"=>"<b>Thanks</b> for registering with our site!<br><br>Your account isn't active yet, in a few minutes you will receive an e-mail explaining how to activate your registration.",
"NEWUSER_MSG_TITLE2"=>"Thanks for resgistering!",
"NEWUSER_MSG_TEXT2"=>"<b>Thanks</b> for registering with our site!<br><br>Now you can login at our site.",
"NEWUSER_FORM_TITLE"=>"Register",
"NEWUSER_ACTIVATE_ERROR"=>"User/session invalid or account already registred.",
"NEWUSER_ACTIVATED"=>"Your account has been activated! Now you can post messages in the forums and send messages to others users on this site. To see the list of users and add them to your list to send them messages, go to \"My Account\" and click in the \"add users\".<br><br>Thanks for registering!",
"NEW_USER_LINK"=>"Register",
//Login
"LOGIN_TITLE"=>"Login",
"LOGIN_NAME"=>"Login:",
"LOGIN_PASSWD"=>"Password:",
"LOGIN_BUTTON"=>"Login",
"LOGIN_REGISTER"=>"Register, it's free!",
"LOGIN_LOST_PWD"=>"Lost your password?",
"LOGIN_WELCOME"=>"Welcome %s",
"LOGIN_LOGOUT"=>"logout",
"LOGIN_AUTOLOGIN"=>"remember me",

//Users online
"USERS_ONLINE"=>"Users Online",
"USERS_ONLINE_TEXT"=>"There are:<br>%d registered users<br>and %d guests %sonline%s now.",

//List users
"LIST_USERS_TITLE"=>"User list",

// Lost your password?
"PASSWD_TITLE"=>"Password Recovery",
"PASSWD_MAIL_TITLE"=>"Password recovery at ",
"PASSWD_MAIL_TEXT1"=>"You've requested that we send your password to you at %s\n\nlogin: %s\npassword: %s",
"PASSWD_MAIL_TEXT2"=>"But your account is not active. To activate your account, please go to the URL below:\n",
"PASSWD_MAIL_DONE"=>"An e-mail was sent to you with your login information.",
"PASSWD_MAIL_ERROR"=>"Could not send the e-mail. Internal error.<br>",
"PASSWD_TEXT"=>"Lost your password? Need to get the activation e-mail again? We can send it to you! Just complete the form with your e-mail and we will send your login information. Use it only to retrieve YOUR password.",
"PASSWD_FORM_EMAIL"=>"Enter your e-mail:",
"PASSWD_FORM_SUBMIT"=>"Recover password",

//stats
"STATS_TITLE"=>"Statistics",
"STATS_USERS"=>"Users registered",
"STATS_ACTIVE"=>"Active",
"STATS_NOTACTIVE"=>"Not active",
"STATS_TOTAL"=>"Total",
"STATS_TOPTEN"=>"Topten countries",
"STATS_LAST_WEEK"=>"New users this week",
"STATS_LAST_MONTHS"=>"New users / 3 months",

//send e-mail
"SENDMAIL_MSG_HDR"=>"Hello, %s, \n\n",
"SENDMAIL_MSG_FTR"=>"\n\nSee you,\n\n%s\n\nThis e-mail was sent because you registered at %s. If you don't want to receive any e-mail from us, please edit your account profile at this site.",
"SENDMAIL_MAIL_SENT"=>"Sent",
"SENDMAIL_USER"=>"User",
"SENDMAIL_EMAIL"=>"E-mail",
"SENDMAIL_COUNTRY"=>"Country",
"SENDMAIL_SEND"=>"Send",
"SENDMAIL_TEXT"=>"Text",
"SENDMAIL_SUBMIT"=>"Send e-mail",
"SENDMAIL_ACCTO"=>"Send e-mail to users that:",
"SENDMAIL_ACCNEWS"=>"Accepts news",
"SENDMAIL_ACCFREL"=>"Accepts new file releases",
"SENDMAIL_CONTINUE"=>"Continue sending",

// Avatars
"AVATAR_TITLE"=>"Choose your Avatar",
"AVATAR_NONE"=>"none/remove current",
"AVATAR_SELECT"=>"Select your avatar:",
"AVATAR_UPLOAD"=>"or upload a new avatar: (100x100).(jpg|gif|png)",

// Admmenu
"ADMMNU_INFO"=>"Info",
"ADMMNU_WEBADMIN"=>"WebAdmin",
"ADMMNU_SENDEMAIL"=>"Send e-mail",
"ADMMNU_USERS"=>"Users",
"ADMMNU_USERACCESS"=>"User Access",
"ADMMNU_MENU"=>"Menu",

"SIDEBOX_EDIT_TITLE"=>"Side Boxes"
);

?>
